@@ -57,6 +57,9 @@ class ExtremePluginManager:
     def enable_events(self):
         self._disable_events = False
 
+    def are_events_disabled(self) -> bool:
+        return self._disable_events
+
     def stdout(self, *args, sep=' ', end='\n', file=None):
         print(*args, sep=sep, end=end, file=file)
 
