@@ -56,6 +56,9 @@ class BasePlugin(abc.ABC):
         )
 
     def reload(self):
+        if self._plugin_manager.are_events_disabled():
+            return
+
         self._bytecode = self._builtin_funcs.copy()
 
         path = os.path.abspath(self._path)
@@ -146,9 +149,6 @@ class BasePlugin(abc.ABC):
         return self.write_file_bytes(path, contents.encode(encoding))
 
     def execute_event(self, event: str, *args, **kwargs):
-        if not self._enabled:
-            return
-
         path = os.path.abspath(self._path)
         sys.path.append(path)
 
